@@ -1,9 +1,6 @@
 from typing import List
 
-from mcwb.types import Vec3
-from mcwb.volume import Volume
-
-from mciwb import Direction
+from mciwb.imports import Direction, Vec3, Volume
 from tests.conftest import ENTITY_NAME
 from tests.mockclient import MockClient
 
